==> kubernetes-model-admissionregistration-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SelfSubjectRulesReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SelfSubjectRulesReviewFluent<A extends SelfSubjectRulesReviewFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> withNewMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public SelfSubjectRulesReviewFluent.MetadataNested<A> editMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> editOrNewMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SelfSubjectRulesReviewSpec getSpec();
  public SelfSubjectRulesReviewSpec buildSpec();
  public A withSpec(SelfSubjectRulesReviewSpec spec);
  public Boolean hasSpec();
  public A withNewSpec(String namespace);
  public SelfSubjectRulesReviewFluent.SpecNested<A> withNewSpec();
  public SelfSubjectRulesReviewFluent.SpecNested<A> withNewSpecLike(SelfSubjectRulesReviewSpec item);
  public SelfSubjectRulesReviewFluent.SpecNested<A> editSpec();
  public SelfSubjectRulesReviewFluent.SpecNested<A> editOrNewSpec();
  public SelfSubjectRulesReviewFluent.SpecNested<A> editOrNewSpecLike(SelfSubjectRulesReviewSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubjectRulesReviewStatus getStatus();
  public SubjectRulesReviewStatus buildStatus();
  public A withStatus(SubjectRulesReviewStatus status);
  public Boolean hasStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> withNewStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> withNewStatusLike(SubjectRulesReviewStatus item);
  public SelfSubjectRulesReviewFluent.StatusNested<A> editStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> editOrNewStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> editOrNewStatusLike(SubjectRulesReviewStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<SelfSubjectRulesReviewFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,SelfSubjectRulesReviewSpecFluent<SelfSubjectRulesReviewFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,SubjectRulesReviewStatusFluent<SelfSubjectRulesReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SelfSubjectRulesReviewFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SelfSubjectRulesReviewFluent<A extends SelfSubjectRulesReviewFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> withNewMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public SelfSubjectRulesReviewFluent.MetadataNested<A> editMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> editOrNewMetadata();
  public SelfSubjectRulesReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SelfSubjectRulesReviewSpec getSpec();
  public SelfSubjectRulesReviewSpec buildSpec();
  public A withSpec(SelfSubjectRulesReviewSpec spec);
  public Boolean hasSpec();
  public A withNewSpec(String namespace);
  public SelfSubjectRulesReviewFluent.SpecNested<A> withNewSpec();
  public SelfSubjectRulesReviewFluent.SpecNested<A> withNewSpecLike(SelfSubjectRulesReviewSpec item);
  public SelfSubjectRulesReviewFluent.SpecNested<A> editSpec();
  public SelfSubjectRulesReviewFluent.SpecNested<A> editOrNewSpec();
  public SelfSubjectRulesReviewFluent.SpecNested<A> editOrNewSpecLike(SelfSubjectRulesReviewSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubjectRulesReviewStatus getStatus();
  public SubjectRulesReviewStatus buildStatus();
  public A withStatus(SubjectRulesReviewStatus status);
  public Boolean hasStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> withNewStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> withNewStatusLike(SubjectRulesReviewStatus item);
  public SelfSubjectRulesReviewFluent.StatusNested<A> editStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> editOrNewStatus();
  public SelfSubjectRulesReviewFluent.StatusNested<A> editOrNewStatusLike(SubjectRulesReviewStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<SelfSubjectRulesReviewFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,SelfSubjectRulesReviewSpecFluent<SelfSubjectRulesReviewFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,SubjectRulesReviewStatusFluent<SelfSubjectRulesReviewFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
